import tarfile
import bz2
import shutil
from .base_extractor import BaseExtractor
from .utils import is_bzip2


class BZ2Extractor(BaseExtractor):
    """Extractor for Gzip files."""

    def __init__(
        self, cache: bool = True, delete_original_after_extraction: bool = True
    ):
        """Create new GzipExtractor object.

        Parameters
        -------------------
        cache: bool = True,
            Whether to skip extraction when file is already available.
        delete_original_after_extraction: bool = True,
            Whether to delete the original file after it has been extracted.
        """
        super().__init__(
            extension=".bz2",
            cache=cache,
            delete_original_after_extraction=delete_original_after_extraction,
        )

    def can_extract(self, source: str) -> bool:
        """Return Whether this extractor can extract or not the given file.

        Parameters
        --------------------
        source: str,
            The source path to test if it can be extracted.

        Returns
        --------------------
        Boolean value representing if the file can be extracted.
        """
        return is_bzip2(source)

    def _extract(self, source: str, destination: str):
        """Extract the given source to the given destination.

        Parameters
        ------------------
        source: str,
            The source file.
        destination: str,
            The target destination.
        """
        with bz2.open(source, "rb") as f_in:
            with open(destination, "wb") as f_out:
                shutil.copyfileobj(f_in, f_out)
